FastMBAR API
============

..
   .. currentmodule:: FastMBAR
   .. autoclass:: FastMBAR::FastMBAR
      .. automethod:: __init__
      .. rubric:: Attributes
      .. autoattribute:: energy	       

..
   .. autoclass:: FastMBAR::FastMBAR
      :special-members: __init__
      :members:


.. autoclass:: FastMBAR::FastMBAR
   :special-members: __init__
   :members:
	     



	     
		    
	  
		   
